#Tamanhos

LARGURA_TELA = 800
ALTURA_TELA = 700
LARGURA_JOGO = 300
ALTURA_JOGO = 500
TAMANHO_PECA = 30
NUM_BLOCOS_HOR = 10
NUM_BLOCOS_VERT = 20


#cores
VERMELHO = (255, 0, 0)
ROXO = (148, 0, 211)
AZUL_CLARO = (0, 191, 255)
AZUL_ESCURO = (0, 0, 255)
AMARELO = (255, 255, 0)
ROSA = (255, 20, 147)
VERDE = (0, 255, 0)



import pygame
from .pecas import *
from .constantes import *
import random
import sys
 

pygame.font.init()


pos_x = (LARGURA_TELA - LARGURA_JOGO) // 2
pos_y = (ALTURA_TELA - ALTURA_JOGO) // 2

cores_pecas = [VERMELHO, ROXO, AZUL_CLARO, AZUL_ESCURO, AMARELO, ROSA, VERDE]
formatos = [S, Z, I, O, J, L, T]

class Pecas(object):
    def __init__(self, x, y, formato):
        self.x = x
        self.y = y
        self.formato = formato
        self.cor = cores_pecas[formatos.index(formato)]
        self.rotation = 0

def gerar_grid(tela):
    for j in range(0, 9):
        for i in range(0, 19):
            retang = pygame.Rect(j*30 + pos_x, i*30 + 50, 60, 60)
            pygame.draw.rect(tela, AZUL_CLARO, retang, 2)


def exibir_tela():
    pygame.init()
    tela = pygame.display.set_mode((LARGURA_TELA, ALTURA_TELA))
    pygame.display.set_caption('Pytetris')
    return tela

def loop(tela):
    while True:
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                pygame.quit()
                sys.exit()
        gerar_grid(tela)
        pygame.display.update()



def main():
    tela = exibir_tela()
    loop(tela)
        

if __name__ == "__main__":
    main()
